@@ -37,16 +37,16 @@ covMest <- function(x, cor=FALSE,  r = 0.45, arp = 0.05, eps=1e-3, maxiter=120,
 
     ## if not provided initial estimates, compute them as MCD 
     if(missing(t0) || missing(S0)){
-        mcd <- covMcd(x)
-        t0 <- mcd$raw.center
-        S0 <- mcd$raw.cov
+        mcd <- CovMve(x)
+        t0 <- mcd@raw.center
+        S0 <- mcd@raw.cov
     }
 
     ## calculate the constants M and c 
     ## for the translated biweight function
     psix <- new("PsiBwt", n=n, p=p, r=r, alpha=arp)
     psix <- csolve(psix)
-    mest <- iterM(psix, x, t0, S0, eps=1e-3, maxiter=20)
+    mest <- iterM(psix, x, t0, S0, eps=1e-3, maxiter=maxiter)
 
     ## this was the version without OO
     ##const <- csolve.bt(n, p, r, arp)
